# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pygwalker']

package_data = \
{'': ['*'], 'pygwalker': ['templates/*']}

install_requires = \
['ipython>=8.10.0,<9.0.0', 'jinja2>=3.1.2,<4.0.0', 'pandas>=1.5.3,<2.0.0']

setup_kwargs = {
    'name': 'pygwalker',
    'version': '0.0.1',
    'description': 'pygwalker: Combining Jupyter Notebook with a Tableau-like UI',
    'long_description': '<p align="center"><a href="#"><img width=60% alt="" src="https://docs-us.oss-us-west-1.aliyuncs.com/img/pygwalker/screenshot-top-img.png"></a></p>\n<h2 align="center">pygwalker: Combining Jupyter Notebook with a Tableau-like UI</h2>\n\n<p align="center">\n    <a href="https://badge.fury.io/py/pygwalker">\n        <img src="https://badge.fury.io/py/pygwalker.svg" alt="PyPI version" height="18" align="center">\n    </a>\n    <a href="https://discord.gg/Z4ngFWXz2U">\n      <img alt="Discord" src="https://img.shields.io/discord/987366424634884096" alt=\'Discord\' align="center"/>\n    </a>\n    <a href=\'https://twitter.com/intent/follow?original_referer=https%3A%2F%2Fpublish.twitter.com%2F&ref_src=twsrc%5Etfw&screen_name=kanaries_data&tw_p=followbutton\'>\n        <img alt="Twitter Follow" src="https://img.shields.io/twitter/follow/kanaries_data?style=social" alt=\'Twitter\' align="center"/>\n    </a>\n</p>\n\nPygwalker can simplify your Jupyter Notebook data analysis and data visualization workflow. By bringing a lightweight, easy-to-use, Tableau-like interface instead of analyzing data using Python.\n\nPygwalker intergrates Jupyter Notebook with [Graphic Walker](https://github.com/Kanaries/graphic-walker), a different type of open-source alternative to Tableau. It allows data scientists to analyze data and visualize patterns with simple drag-and-drop operations.\n     \nVisit [Graphic Walker Online Demo](https://graphic-walker.kanaries.net/) to test it out!\n\n> Pygwalker will add more support such as R in the future.\n\n# Getting Started\n\n## Setup pygwalker\n\nBefore using pygwalker, make sure to install the packages through the command line using pip.\n\n```bash\npip install pygwalker\n```\n\n## Use pygwalker in Jupyter Notebook\n\nImport pygwalker and pandas to your Jupyter Notebook to get started.\n\n```python    \nimport pandas as pd\nimport pygwalker as pyg\n```\n\nYou can use pygwalker without changing your existing workflow. For example, you can call up Graphic Walker with the dataframe loaded in this way:\n\n```python\ndf = pd.read_csv(\'./bike_sharing_dc.csv)\ngwalker = pyg.GWalker(df)\ngwalker.walk()\n```\n![](https://docs-us.oss-us-west-1.aliyuncs.com/img/pygwalker/screenshot-top-img.png)\n\nThat\'s it. Now you have a Tableau-like user interface to analyze and visualize data by dragging and dropping variables.\n\n[![Manually explore your data with a Tableau-like UI](https://docs-us.oss-us-west-1.aliyuncs.com/img/pygwalker/drag-and-drop.gif)](https://docs.kanaries.net/graphic-walker/overview)\n\nCool things you can do with Graphic Walker:\n\n+ You can change the mark type into others to make different charts, for example, a line chart:\n\n![graphic walker line chart](https://docs-us.oss-us-west-1.aliyuncs.com/images/graphic-walker/gw-line-01.png)\n\n\n+ To compare different measures, you can create a concat view by adding more than one measure into rows/columns.\n\n![graphic walker area chart](https://docs-us.oss-us-west-1.aliyuncs.com/images/graphic-walker/gw-area-01.png)\n\n+ To make a facet view of several subviews divided by the value in dimension, put dimensions into rows or columns to make a facets view. The rules are similar to Tableau.\n\n![graphic walker scatter chart](https://docs-us.oss-us-west-1.aliyuncs.com/images/graphic-walker/gw-scatter-01.png)\n\n+ You can save the data exploration result to a local file.\n\nFor more detailed instructions, visit the [Graphic Walker GitHub page](https://github.com/Kanaries/graphic-walker).\n\n# MIT License\nCopyright (c) 2023-2033 Kanaries Data, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n"Software"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n\n# Resoruces\n\n+ Check out more resources about Graphic Walker on [Graphic Walker GitHub](https://github.com/Kanaries/Rath)\n+ We are also working on [RATH](https://kanaries.net): an Open Source, Automate exploratory data analysis tool that redefines the workflow of data wrangling, exploration and visualization with AI-powered automation. Check out the [RATH website](https://kanaries.net) and [RATH GitHub](https://github.com/Kanaries/Rath) for more!\n+ If you encounter any issues and need support, join our [Slack](https://join.slack.com/t/kanaries/shared_invite/zt-1k60sgaxu-aGcuS7CwGeJUccE61iGopg) or [Discord](https://discord.gg/Z4ngFWXz2U) channels.\n+ Share pygwalker on these social media platforms:\n\n[![GitHub Repo stars](https://img.shields.io/badge/share%20on-reddit-red?style=flat-square&logo=reddit)](https://reddit.com/submit?url=https://github.com/Kanaries/pygwalker&title=Say%20Hello%20to%20pygwalker%3A%20Combining%20Jupyter%20Notebook%20with%20a%20Tableau-like%20UI)\n[![GitHub Repo stars](https://img.shields.io/badge/share%20on-hacker%20news-orange?style=flat-square&logo=ycombinator)](https://news.ycombinator.com/submitlink?u=https://github.com/Kanaries/pygwalker)\n[![GitHub Repo stars](https://img.shields.io/badge/share%20on-twitter-03A9F4?style=flat-square&logo=twitter)](https://twitter.com/share?url=https://github.com/Kanaries/pygwalker&text=Say%20Hello%20to%20pygwalker%3A%20Combining%20Jupyter%20Notebook%20with%20a%20Tableau-like%20UI)\n[![GitHub Repo stars](https://img.shields.io/badge/share%20on-facebook-1976D2?style=flat-square&logo=facebook)](https://www.facebook.com/sharer/sharer.php?u=https://github.com/Kanaries/pygwalker)\n[![GitHub Repo stars](https://img.shields.io/badge/share%20on-linkedin-3949AB?style=flat-square&logo=linkedin)](https://www.linkedin.com/shareArticle?url=https://github.com/Kanaries/pygwalker&&title=Say%20Hello%20to%20pygwalker%3A%20Combining%20Jupyter%20Notebook%20with%20a%20Tableau-like%20UI)\n',
    'author': 'Asm.Def',
    'author_email': 'woojson@zju.edu.cn',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
